==> vokoscreen-ng_3.0.7.orig.tar.gz: vokoscreenNG-3.0.7/src/language/zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个设备</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>摄像头</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>切换至窗口模式</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>切换至全屏</translation>
    </message>
</context>
<context>
    <name>QvkCountdown</name>
    <message>
        <source>Countdown</source>
        <translation>倒计时</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个设备</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>录制未能开始，可用磁盘空间不足。</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>磁盘剩余空间已耗尽。</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁盘空间上限</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>录制已停止，没有足够的磁盘空间。</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>未发现文件管理器。</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>请安装一个文件管理器。</translation>
    </message>
    <message>
        <source>Desktop session is a Wayland session</source>
        <translation>桌面会话为 Wayland 会话</translation>
    </message>
    <message>
        <source>To time Wayland is not supported. A screencast show a black screen. Please logout and start a X11 Desktop session</source>
        <translation>尚不支持 Wayland 录屏功能，您的屏幕广播将会是黑屏画面。请登出并进入 X11 会话。</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>源代码</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻译</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>Wayland desktop session detected</source>
        <translation>检测到 Wayland 桌面会话</translation>
    </message>
</context>
<context>
    <name>QvkPlayer</name>
    <message>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>横向翻转</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>纵向翻转</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>翻转</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰度</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除窗口边框</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>摄像头设置</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒计时</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>视频大小:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>可用磁盘空间:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>录制时间:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>帧率</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>视频编码</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音频编码</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>质量</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要录制鼠标</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>小时</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>分钟</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>开始倒数</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>此时间后停止录制：</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>小时</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>视频路径</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁盘空间上限</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>系统托盘显示</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>开始录制前等待秒数：</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>检查更新</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>可用</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>不可用</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>翻转</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰度</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>发送报告</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>播放最新一次的录制</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>当录制开始时最小化</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>开启时最小化</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>横向翻转</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>纵向翻转</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除窗口边框</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>下次启动时重置所有设置</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>图片版权和许可条款</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>屏幕广播</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>日志</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>图片版权和许可条款</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>上一帧</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>下一帧</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>移动菜单</translation>
    </message>
</context>
</TS>

==> vokoscreen-ng_3.1.0.orig.tar.gz: vokoscreenNG-3.1.0/src/language/zh_CN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>QvkAudioController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个设备</translation>
    </message>
</context>
<context>
    <name>QvkCameraController</name>
    <message>
        <source>Camera</source>
        <translation>摄像头</translation>
    </message>
</context>
<context>
    <name>QvkCameraWindow</name>
    <message>
        <source>Switch to Window</source>
        <translation>切换至窗口模式</translation>
    </message>
    <message>
        <source>Switch to Fullscreen</source>
        <translation>切换至全屏</translation>
    </message>
</context>
<context>
    <name>QvkDirectSoundController</name>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个设备</translation>
    </message>
</context>
<context>
    <name>QvkHelp</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
</context>
<context>
    <name>QvkImageFromTabs</name>
    <message>
        <source>No filemanager found.</source>
        <translation>未发现文件管理器。</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>请安装一个文件管理器。</translation>
    </message>
</context>
<context>
    <name>QvkLimitDiskFreeSpace</name>
    <message>
        <source>Warning</source>
        <translation>警告</translation>
    </message>
    <message>
        <source>The recording is not started, not enough free disk space.</source>
        <translation>录制未能开始，可用磁盘空间不足。</translation>
    </message>
    <message>
        <source>The free disk space limit is reached.</source>
        <translation>磁盘剩余空间已耗尽。</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁盘空间上限</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>The recording was stopped, not enough free disk space.</source>
        <translation>录制已停止，没有足够的磁盘空间。</translation>
    </message>
</context>
<context>
    <name>QvkMainWindow</name>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Window</source>
        <translation>窗口</translation>
    </message>
    <message>
        <source>No filemanager found.</source>
        <translation>未发现文件管理器。</translation>
    </message>
    <message>
        <source>Please install a filemanager.</source>
        <translation>请安装一个文件管理器。</translation>
    </message>
    <message>
        <source>Sourcecode</source>
        <translation>源代码</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>Translations</source>
        <translation>翻译</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐赠</translation>
    </message>
</context>
<context>
    <name>QvkPulseAudioWatcher</name>
    <message>
        <source>Select one or more devices</source>
        <translation>选取一个或多个设备</translation>
    </message>
</context>
<context>
    <name>QvkRegionChoise</name>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
</context>
<context>
    <name>QvkSystray</name>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
</context>
<context>
    <name>QvkSystrayAlternative</name>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>cameraSettingsDialog</name>
    <message>
        <source>Dialog</source>
        <translation>对话框</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>横向翻转</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>纵向翻转</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>翻转</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰度</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除窗口边框</translation>
    </message>
    <message>
        <source>160x120</source>
        <translation>160x120</translation>
    </message>
    <message>
        <source>320x240</source>
        <translation>320x240</translation>
    </message>
    <message>
        <source>Camera settings</source>
        <translation>摄像头设置</translation>
    </message>
    <message>
        <source>640x480</source>
        <translation>640x480</translation>
    </message>
</context>
<context>
    <name>formMainWindow</name>
    <message>
        <source>Area</source>
        <translation>区域</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
    <message>
        <source>Magnification</source>
        <translation>放大</translation>
    </message>
    <message>
        <source>Countdown</source>
        <translation>倒计时</translation>
    </message>
    <message>
        <source>Video size:</source>
        <translation>视频大小:</translation>
    </message>
    <message>
        <source>Free disk space:</source>
        <translation>可用磁盘空间:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>信息</translation>
    </message>
    <message>
        <source>Record Time:</source>
        <translation>录制时间:</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>Frames</source>
        <translation>帧率</translation>
    </message>
    <message>
        <source>Videocodec</source>
        <translation>视频编码</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>格式</translation>
    </message>
    <message>
        <source>Audiocodec</source>
        <translation>音频编码</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>质量</translation>
    </message>
    <message>
        <source>Do not record mouse cursor</source>
        <translation>不要录制鼠标</translation>
    </message>
    <message>
        <source>Hour</source>
        <translation>小时</translation>
    </message>
    <message>
        <source>Minute</source>
        <translation>分钟</translation>
    </message>
    <message>
        <source>Start the timer</source>
        <translation>开始倒数</translation>
    </message>
    <message>
        <source>Stop recording after</source>
        <translation>此时间后停止录制：</translation>
    </message>
    <message>
        <source>Hours</source>
        <translation>小时</translation>
    </message>
    <message>
        <source>Minutes</source>
        <translation>分钟</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>秒</translation>
    </message>
    <message>
        <source>Videopath</source>
        <translation>视频路径</translation>
    </message>
    <message>
        <source>Limit of free disk space</source>
        <translation>磁盘空间上限</translation>
    </message>
    <message>
        <source>Show in systray</source>
        <translation>系统托盘显示</translation>
    </message>
    <message>
        <source>Second wait before recording</source>
        <translation>开始录制前等待秒数：</translation>
    </message>
    <message>
        <source>Look for updates</source>
        <translation>检查更新</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Available</source>
        <translation>可用</translation>
    </message>
    <message>
        <source>Not available</source>
        <translation>不可用</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>继续</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>摄像头</translation>
    </message>
    <message>
        <source>Invert</source>
        <translation>翻转</translation>
    </message>
    <message>
        <source>Gray</source>
        <translation>灰度</translation>
    </message>
    <message>
        <source>Send Report</source>
        <translation>发送报告</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F10</source>
        <translation>CTRL+SHIFT+F10</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F11</source>
        <translation>CTRL+SHIFT+F11</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F12</source>
        <translation>CTRL+SHIFT+F12</translation>
    </message>
    <message>
        <source>Play last record</source>
        <translation>播放最新一次的录制</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>打开文件夹</translation>
    </message>
    <message>
        <source>CTRL+SHIFT+F8</source>
        <translation>CTRL+SHIFT+F8</translation>
    </message>
    <message>
        <source>Minimized when recording starts</source>
        <translation>当录制开始时最小化</translation>
    </message>
    <message>
        <source>Starts minimized</source>
        <translation>开启时最小化</translation>
    </message>
    <message>
        <source>Flip horizontal</source>
        <translation>横向翻转</translation>
    </message>
    <message>
        <source>Flip vertical</source>
        <translation>纵向翻转</translation>
    </message>
    <message>
        <source>Black-and-white</source>
        <translation>黑白</translation>
    </message>
    <message>
        <source>Remove window frame</source>
        <translation>移除窗口边框</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>捐赠</translation>
    </message>
    <message>
        <source>Reset all settings at the next start</source>
        <translation>下次启动时重置所有设置</translation>
    </message>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>图片版权和许可条款</translation>
    </message>
    <message>
        <source>Megabyte</source>
        <translation>MB</translation>
    </message>
    <message>
        <source>Screencast</source>
        <translation>屏幕广播</translation>
    </message>
    <message>
        <source>Player</source>
        <translation>播放器</translation>
    </message>
    <message>
        <source>Log</source>
        <translation>日志</translation>
    </message>
</context>
<context>
    <name>license</name>
    <message>
        <source>Copyright and license from pictures</source>
        <translation>图片版权和许可条款</translation>
    </message>
</context>
<context>
    <name>player</name>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暂停</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏模式</translation>
    </message>
    <message>
        <source>Previous frame</source>
        <translation>上一帧</translation>
    </message>
    <message>
        <source>Next frame</source>
        <translation>下一帧</translation>
    </message>
    <message>
        <source>Mute</source>
        <translation>静音</translation>
    </message>
    <message>
        <source>Move menu</source>
        <translation>移动菜单</translation>
    </message>
</context>
</TS>
